# LPBI Data Extraction Project
### Thank you for visiting! ![](https://visitor-badge.glitch.me/badge?page_id=AbhisarAnand.LPBI_Data_Extraction_Project)

This repository contains code which extracts the view data of every post from WordPress.

## Documentation
The documentation can be found at: [https://lpbi-views-project.sidepage.co/](https://lpbi-views-project.sidepage.co/)
